# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.utils.encoding import python_2_unicode_compatible
from django.conf import settings
from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel


@python_2_unicode_compatible
class Carriage(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores carriages:
    frw - CARRIAGE FORWARD - PORTO ASSEGNATO
    pad - CARRIAGE PAID - PORTO FRANCO
    exw - EX WORKS" - EX WORKS
    pdc - CARRIAGE PAID W/CHARGE - PORTO FRANCO CON ADDEBITO
    """
    code = models.CharField(
        max_length=3,
        verbose_name=_("Code")
    )
    name = models.CharField(
        max_length=50,
        verbose_name=_("Name")
    )
    slug = models.SlugField(
        db_index=True,
        max_length=50,
        verbose_name=_("Slug"),
        help_text=_("Used for URLs, auto-generated from name if blank"),
    )
    description = models.TextField(
        blank=True,
        verbose_name=_("Description")
    )

    class Meta:
        verbose_name = _('Carriage')
        verbose_name_plural = _('Carriages')
        ordering = ('ordering', 'name')
        permissions = (
            ("view_carriage", "Can view carriage"),
        )

    def __str__(self):
        return self.name


@python_2_unicode_compatible
class Delivery (DateModel, UserModel, StatusModel, OrderedModel):
    """
    Stores deliveries
    """
    transport_by = models.CharField(
        max_length=3,
        choices=settings.CARRIAGE_TRANSPORTBY_DEF,
        verbose_name=_('Transport by'),
    )
    carriage = models.ForeignKey(
        Carriage,
        verbose_name=_('Carriage'),
    )

    class Meta:
        verbose_name = _('Delivery')
        verbose_name_plural = _('Deliveries')
        ordering = ('ordering', 'transport_by', 'carriage')
        permissions = (
            ("view_delivery", "Can view delivery"),
        )

    def __str__(self):
        return "%(transport_by)s - %(carriage)s" % {
            'transport_by': self.get_transport_by_display(),
            'carriage': self.carriage
        }